@@ -43,7 +43,7 @@ sub get_contacts {
         $self->errstr("Wrong Username or Password");
         return;
     }
-	my $url = "http://www.google.com/m8/feeds/contacts/default/full"
+	my $url = "https://www.google.com/m8/feeds/contacts/default/full"
 		. "?max-results=9999&alt=json";
 	$url .= "&v=3.0";					# Gives more fields
     $self->get($url, $self->authsub->auth_params)
@@ -71,7 +71,6 @@ sub make_contact {
 
 	my %orig = %$in;
 	my $out = {};
-
 	my $name;
 	if (my $n = delete $in->{'gd$name'}) {
 		$name = $n->{'gd$fullName'}->{'$t'};
@@ -86,6 +85,19 @@ sub make_contact {
 		}
 	}
 
+        my @links;
+        local $_ = delete $in->{link}
+                and @links = @$_;
+
+        foreach (@links)
+        {
+                if ($_->{type} eq 'image/*' && exists $_->{'gd$etag'}) {
+                        (my $href = $_->{href}) =~ s/\?v=3\.0//;
+                        $out->{photo}{href} = $href;
+                        $out->{photo}{content} = sub { $self->ua->get($href, $self->authsub->auth_params)->decoded_content() };
+                }
+        }
+
 	# $out->{emails} = [[ADDRESS, TYPE], ...]
 	my @emails;
 	local $_ = delete $in->{'gd$email'}
@@ -108,16 +120,26 @@ sub make_contact {
 
 	# $out->{addresses} = [[TYPE => ADDRESS], ...]
 	my @ads;
+        my @postal_ads;
 	$_ = delete $in->{'gd$structuredPostalAddress'}
 		and @ads = @$_;
 	foreach (@ads)
 	{
+                my $address;
+                ($address->{street1}, $address->{street2}) = split /\n/, delete $_->{'gd$street'}{'$t'};
+                $address->{postal_code} = delete $_->{'gd$postcode'}{'$t'};
+                $address->{city} = delete $_->{'gd$city'}{'$t'};
+                $address->{state} = delete $_->{'gd$region'}{'$t'};
+                $address->{country} = delete $_->{'gd$country'}{'$t'};
+
 		my ($type) = (delete $_->{rel}) =~ /#(.*)/;
 		$_ = (delete $_->{'gd$formattedAddress'})->{'$t'};
 		s/\s+$//g; s/\n/, /g;
 		$_ = [$_, $type];
+                push @postal_ads, $address;
 	}
 	$out->{addresses} = \@ads if (@ads);
+        $out->{postal_addresses} = \@postal_ads if (@postal_ads);
 
 	my @events;
 	$_ = delete $in->{'gContact$event'}
